@@ -6,7 +6,6 @@ from dataclasses import asdict
 from dataclasses import dataclass
 from datetime import datetime
 from random import randint
-from typing import Tuple
 
 import numpy as np
 import pytest
@@ -36,7 +35,7 @@ class FakeConstantDb:
     MINIMUM_CADENCE: float = 10.0
     MAXIMUM_CADENCE: float = 10.0
     VARIANCE_CADENCE: float = 0.0
-    STOKES_PARAMS: Tuple[str] = (
+    STOKES_PARAMS: tuple[str] = (
         "I",
         "Q",
         "U",
